
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class EduActionButton extends StatelessWidget {
  final bool buttonWithLeftIcon;
  final bool buttonWithRightIcon;
  final Color containerColor;
  final Color textColor;
  final bool isBorder;
  final bool isColored;
  final bool onlyIcon;
  final bool isDisabled;
  final String text;
  final Widget iconWidget;
  //paddings
  final double verticalPadding;
  final double horizontalPadding;
  const EduActionButton({
    super.key,
   required this.iconWidget,
    this.buttonWithLeftIcon = false,
    this.buttonWithRightIcon = false,
    this.containerColor = Colors.black,
    this.isBorder = false,
    this.isColored = false,
    this.text = "",
    this.textColor = Colors.white,
    required this.verticalPadding,
    required this.horizontalPadding,
    this.isDisabled = false,
    this.onlyIcon = false,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.only(
        top: verticalPadding,
        bottom: verticalPadding,
        left: buttonWithLeftIcon ? horizontalPadding - 4 : horizontalPadding,
        right: buttonWithRightIcon ? horizontalPadding - 4 : horizontalPadding,
      ),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(9),
        color: isDisabled
            ? const Color(0xFFE2E8F0)
            : isBorder
                ? Colors.transparent
                : containerColor,
        border: Border.all(
          color: isDisabled
              ? const Color(0xFFE2E8F0)
              : isBorder
                  ? const Color(0xFFE2E8F0)
                  : containerColor,
        ),
      ),
      child: onlyIcon
          ?iconWidget
          : Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                buttonWithLeftIcon
                    ? iconWidget
                    : const SizedBox(),
                Text(
                  text,
                  style: GoogleFonts.inter(
                    color: isDisabled
                        ? const Color(0xFFB4BFCD)
                        : isBorder
                            ? containerColor
                            : Colors.white,
                    fontWeight: FontWeight.w500,
                  ),
                ),
                buttonWithRightIcon
                    ? iconWidget
                    : const SizedBox(),
              ],
            ),
    );
  }
}
